"""
This document contains all the ground surface temperatures and geothermal fluxes for regions in Europe.
This data was obtained from the publicly available EED_database (http://buildingphysics.com/download/EED_Database.zip) (last visited: 06/10/2023).

The naming convention for the countries comes from Xing, 2014, ESTIMATIONS OF UNDISTURBED GROUND TEMPERATURES USING NUMERICAL AND ANALYTICAL MODELING, PhD. thesis, Oklahoma State University.
"""

DATASET = {
'AUT-Bregenz': (9.5, 0.080),
'AUT-Eisenstadt': (10.4, 0.080),
'AUT-Graz': (9.5, 0.100),
'AUT-Innsbruck': (9.4, 0.060),
'AUT-Linz': (9.5, 0.080),
'AUT-Klagenfurt': (8.1, 0.080),
'AUT-Obergurgl': (2.8, 0.060),
'AUT-Salzburg': (9.0, 0.070),
'AUT-St.Poelten': (9.4, 0.070),
'AUT-Wien': (11.6, 0.060),
'BEL-Antwerpen': (9.6, 0.070),
'BEL-Brussels': (9.7, 0.080),
'BEL-Gent': (9.5, 0.080),
'BEL-Spa': (7.4, 0.060),
'BEL-St.Hubert': (6.8, 0.060),
'BGR-Sofia': (10.4, 0.080),
'BGR-Varna': (12.1, 0.060),
'HRV-Zagreb': (11.3, 0.090),
'HRV-Split': (15.9, 0.040),
'CZE-Brno': (8.7, 0.050),
'CZE-Prague': (7.8, 0.070),
'CZE-Ostrava': (8.2, 0.070),
'DNK-Aalborg': (7.5, 0.070),
'DNK-Copenhagen': (8.6, 0.060),
'DNK-Roenne/Bornh.': (8.3, 0.080),
'DNK-Thorshavn/Faer.': (6.5, 0.070),
'EST-Tallin': (5.2, 0.040),
'EST-Tartu': (4.8, 0.030),
'FIN-Jyvaeskylae': (2.6, 0.040),
'FIN-Helsinki': (5.6, 0.050),
'FIN-Lappeenranta': (3.6, 0.030),
'FIN-Oulu': (2.0, 0.040),
'FIN-Sodankylae': (-1.0, 0.030),
'FIN-Turku': (4.8, 0.040),
'FRA-Ajaccio(Corse)': (14.8, 0.080),
'FRA-Bordeaux': (12.4, 0.090),
'FRA-Brest': (10.9, 0.090),
'FRA-Lille': (9.9, 0.070),
'FRA-Marseille': (14.8, 0.050),
'FRA-Montpellier': (13.9, 0.090),
'FRA-Lyon': (11.9, 0.090),
'FRA-Nantes': (11.2, 0.080),
'FRA-Nice': (15.0, 0.050),
'FRA-Paris': (12.1, 0.070),
'FRA-Strasbourg': (10.0, 0.100),
'FRA-Toulouse': (12.6, 0.080),
'FRA-Tours': (11.2, 0.070),
'DEU-Aachen': (9.7, 0.070),
'DEU-Ansbach': (8.3, 0.090),
'DEU-Augsburg': (8.3, 0.080),
'DEU-Bamberg': (8.5, 0.080),
'DEU-Berlin': (9.0, 0.070),
'DEU-Bochum': (10.0, 0.080),
'DEU-Braunlage(Harz)': (5.9, 0.070),
'DEU-Bremen': (8.8, 0.060),
'DEU-Chemnitz': (7.9, 0.050),
'DEU-Cottbus': (8.9, 0.060),
'DEU-Darmstadt': (10.0, 0.080),
'DEU-Donauesching': (7.0, 0.090),
'DEU-Dortmund': (9.6, 0.080),
'DEU-Dresden': (8.9, 0.060),
'DEU-Duesseldorf': (10.3, 0.080),
'DEU-Emden': (9.0, 0.060),
'DEU-Erfurt': (7.9, 0.060),
'DEU-Essen': (9.6, 0.070),
'DEU-Feldberg(Schw.)': (3.3, 0.070),
'DEU-Feldberg(Ts.)': (5.6, 0.070),
'DEU-Fichtelb.(Erz.)': (2.9, 0.070),
'DEU-Flensburg': (8.2, 0.070),
'DEU-Frankfurt/Ma': (9.7, 0.070),
'DEU-Frankfurt/Od': (8.7, 0.070),
'DEU-Freiberg': (7.7, 0.060),
'DEU-Freiburg Brsg.': (10.4, 0.090),
'DEU-Fulda': (8.0, 0.070),
'DEU-Garmisch-P.': (6.5, 0.080),
'DEU-Giessen': (9.0, 0.070),
'DEU-Goerlitz': (8.2, 0.060),
'DEU-Guetersloh': (9.2, 0.070),
'DEU-Halle/Saale': (9.7, 0.070),
'DEU-Hamburg': (8.9, 0.060),
'DEU-Hannover': (8.9, 0.060),
'DEU-Heide/Holst.': (8.3, 0.050),
'DEU-Hof': (6.9, 0.060),
'DEU-Jena': (9.3, 0.060),
'DEU-Kaiserslautern': (9.4, 0.080),
'DEU-Karlsruhe': (10.3, 0.120),
'DEU-Kassel': (8.5, 0.070),
'DEU-Kiel': (8.4, 0.060),
'DEU-Koeln': (10.4, 0.080),
'DEU-Konstanz': (9.0, 0.090),
'DEU-Leipzig': (8.8, 0.060),
'DEU-Magdeburg': (8.7, 0.060),
'DEU-Mannheim': (10.2, 0.110),
'DEU-Muenchen': (8.0, 0.080),
'DEU-Muenster': (9.2, 0.060),
'DEU-Neubrandenburg': (7.9, 0.080),
'DEU-Norderney': (9.0, 0.060),
'DEU-Nuernberg': (8.7, 0.080),
'DEU-Oberstdorf': (6.1, 0.080),
'DEU-Osnabrueck': (9.1, 0.070),
'DEU-Potsdam': (8.7, 0.070),
'DEU-Regensburg': (8.2, 0.080),
'DEU-Rendsburg': (8.2, 0.060),
'DEU-Rosenheim': (8.3, 0.070),
'DEU-Rostock': (8.4, 0.080),
'DEU-Saarbruecken': (9.0, 0.080),
'DEU-Schweinfurt': (8.8, 0.080),
'DEU-Schwerin': (8.4, 0.070),
'DEU-Stuttgart': (9.1, 0.080),
'DEU-Trier': (9.9, 0.070),
'DEU-Ulm': (7.9, 0.080),
'DEU-Wuerzburg': (9.2, 0.080),
'DEU-Zugspitze': (-4.8, 0.070),
'GRC-Athens': (17.7, 0.110),
'GRC-Iraklion': (18.7, 0.070),
'GRC-Kalamata': (17.8, 0.080),
'GRC-Kerkyra': (17.5, 0.080),
'GRC-Larissa': (15.7, 0.110),
'GRC-Rhodos': (19.0, 0.200),
'GRC-Thessaloniki': (16.2, 0.080),
'HUN-Budapest': (10.4, 0.070),
'HUN-Debrecen': (9.9, 0.100),
'HUN-Gyoer': (10.4, 0.070),
'HUN-Miskolc': (9.2, 0.100),
'HUN-Pecs': (10.4, 0.080),
'HUN-Szeged': (10.4, 0.100),
'ISL-Reykjavik': (4.3, 0.150),
'IRL-Cork': (9.4, 0.060),
'IRL-Dublin': (9.5, 0.070),
'IRL-Shannon': (10.1, 0.050),
'ITA-Bari': (15.7, 0.080),
'ITA-Bologna': (13.4, 0.060),
'ITA-Bolzano': (11.6, 0.060),
'ITA-Cagliari(Sar': (16.4, 0.080),
'ITA-Catania': (17.9, 0.040),
'ITA-Cortina d Am': (6.6, 0.060),
'ITA-Firenze': (14.8, 0.100),
'ITA-Genova': (15.4, 0.090),
'ITA-Milano': (11.4, 0.060),
'ITA-Messina': (18.2, 0.040),
'ITA-Napoli': (15.5, 0.050),
'ITA-Palermo': (18.5, 0.060),
'ITA-Roma': (15.5, 0.100),
'ITA-Torino': (12.6, 0.050),
'ITA-Trieste': (14.2, 0.050),
'ITA-Venezia': (12.7, 0.040),
'ITA-Volterra(Tus': (14.0, 0.200),
'LVA-Liepaja': (6.7, 0.030),
'LVA-Riga': (6.1, 0.050),
'LIE-Vaduz': (9.2, 0.070),
'LTU-Kaunas': (6.5, 0.030),
'LTU-Klaipeda': (7.0, 0.070),
'LTU-Vilnius': (6.0, 0.040),
'LUX-Luxembourg': (8.3, 0.070),
'MKD-Bitola': (11.0, 0.070),
'MKD-Skopje': (11.3, 0.080),
'NLD-Amsterdam': (9.8, 0.070),
'NLD-Eindhoven': (9.9, 0.060),
'NLD-Groningen': (9.2, 0.080),
'NLD-Maastricht': (9.5, 0.060),
'NLD-Rotterdam': (10.0, 0.070),
'NLD-Utrecht': (9.8, 0.090),
'NOR-Bergen': (7.7, 0.050),
'NOR-Bodoe': (4.5, 0.050),
'NOR-Oslo': (5.7, 0.050),
'NOR-Stavanger': (7.3, 0.050),
'NOR-Tromsoe': (2.5, 0.040),
'NOR-Trondheim': (4.7, 0.050),
'NOR-Vardoe': (1.3, 0.060),
'POL-Bialystok': (6.7, 0.040),
'POL-Krakow': (8.6, 0.060),
'POL-Poznan': (8.2, 0.070),
'POL-Szczecin': (8.4, 0.070),
'POL-Warsaw': (7.8, 0.070),
'POL-Wroclaw': (8.3, 0.060),
'PRT-Faro': (17.2, 0.080),
'PRT-Lisboa': (16.8, 0.070),
'PRT-Porto': (14.5, 0.070),
'ROU-Galati': (10.5, 0.050),
'ROU-Bucharest': (10.6, 0.040),
'ROU-Cluj': (8.2, 0.050),
'ROU-Constanta': (11.5, 0.040),
'ROU-Craiova': (10.6, 0.050),
'ROU-Iasi': (9.4, 0.050),
'ROU-Oradea': (10.2, 0.090),
'ROU-Sibiu': (8.5, 0.070),
'ROU-Timisoara': (10.6, 0.070),
'SRB-Belgrade': (11.8, 0.110),
'SVK-Bratislava': (9.9, 0.060),
'SVK-Kosice': (9.0, 0.080),
'SVK-Poprad': (5.8, 0.060),
'SVN-Ljubljana': (9.6, 0.070),
'ESP-Alicante': (17.9, 0.070),
'ESP-Almeria': (18.5, 0.070),
'ESP-Barcelona': (15.3, 0.070),
'ESP-Bilbao': (14.0, 0.070),
'ESP-Cordoba': (17.5, 0.090),
'ESP-La Coruna': (14.1, 0.100),
'ESP-Madrid': (13.9, 0.080),
'ESP-Malaga': (18.0, 0.050),
'ESP-Mallorca': (15.8, 0.060),
'ESP-Murcia': (18.0, 0.070),
'ESP-Santander': (14.2, 0.060),
'ESP-Valladolid': (12.0, 0.090),
'ESP-Zaragoza': (14.6, 0.070),
'SWE-Falun': (5.5, 0.050),
'SWE-G teborg': (7.1, 0.040),
'SWE-J nk ping': (5.3, 0.040),
'SWE-Kiruna': (2.0, 0.040),
'SWE-Lule': (3.6, 0.040),
'SWE-Malm': (8.0, 0.060),
'SWE-stersund': (3.5, 0.060),
'SWE-Stockholm': (6.6, 0.050),
'SWE-Sundsvall': (5.0, 0.050),
'SWE-Ume': (4.5, 0.050),
'SWE-Visby(Gotlan': (6.8, 0.050),
'CHE-Aigle': (9.1, 0.070),
'CHE-Basel': (9.6, 0.090),
'CHE-Bellinzona': (10.6, 0.070),
'CHE-Bern': (8.2, 0.060),
'CHE-Chur': (8.7, 0.060),
'CHE-Delemont': (8.7, 0.070),
'CHE-Geneve': (9.6, 0.070),
'CHE-Jungfraujoch': (-7.9, 0.060),
'CHE-LaChauxdeFon': (5.8, 0.080),
'CHE-Lugano': (11.6, 0.070),
'CHE-Luzern': (8.8, 0.070),
'CHE-Schaffhausen': (8.5, 0.090),
'CHE-St.Gallen': (7.4, 0.070),
'CHE-St.Moritz': (1.2, 0.060),
'CHE-Zermatt': (3.5, 0.060),
'CHE-Zuerich': (8.5, 0.080),
'TUR-Adana': (18.0, 0.060),
'TUR-Ankara': (11.7, 0.070),
'TUR-Istanbul': (14.1, 0.080),
'TUR-Izmir': (17.7, 0.100),
'GRB-Aberdeen': (7.9, 0.040),
'GRB-Belfast': (9.0, 0.050),
'GRB-Edinburgh': (8.4, 0.050),
'GRB-London': (9.5, 0.050),
'GRB-Manchester': (9.4, 0.050),
'GRB-Newcastle-Ty': (8.8, 0.080),
'GRB-Plymouth': (11.0, 0.100)}

LIST_OF_COUNTRY_NAMES = DATASET.keys()
